@@ -1,47 +1,37 @@
-#' @keywords spatial, shapefile
+#' @keywords datagen
 #' @export
+#' @import rvest
 #' @title Convert US County Borders Shapefile
 #' @param nameOnly logical specifying whether to only return the name without creating the file
-#' @param ... additional arguments (unused)
 #' @description A US county borders shapefile is downloaded and converted to a 
-#' SpatialPolygonsDataFrame with additional columns of data. The resulting file wil be created
+#' SpatialPolygonsDataFrame with additional columns of data. The resulting file will be created
 #' in the package \code{SpatialDataDir} which can be set with \code{setSpatialDataDir()}.
-#' @return Large SpatialPolygonsDataFrame
+#' @return Large SpatialPolygonsDataFrame.
 #' @references \url{http://www2.census.gov/geo/tiger/GENZ2013}
-
-
-convertUSCensusCounties <- function(nameOnly=FALSE, ...) {
+convertUSCensusCounties <- function(nameOnly=FALSE) {
   
   # Use package internal data directory
   dataDir <- getSpatialDataDir()
   
-  # Always require a data directory
-  if (is.null(dataDir)) {
-    stop('dataDir must be specified and must be a user writable directory', call.=FALSE)
-  }
-  
   # Specify the name of the dataset and file being created
   datasetName <- 'USCensusCounties'
-  fileName <- paste0(datasetName,'.RData')
     
   if (nameOnly) return(datasetName)
 
-  # Specify URL
+  # Build appropriate request URL for US County Borders
   url = "http://www2.census.gov/geo/tiger/GENZ2013/cb_2013_us_county_20m.zip"
   
   filePath <- paste(dataDir,basename(url),sep='/')
   download.file(url,filePath)
   unzip(filePath,exdir=paste0(dataDir, "/counties"))
   
-  # Create temporary directory to open data in
-  dsnPath <- paste(dataDir,'counties',sep='/')
-  
   # Convert shapefile into SpatialPolygonsDataFrame
-  spDF <- convertLayer(dsn='counties',layerName="cb_2013_us_county_20m")
+  dsnPath <- paste(dataDir,'counties',sep='/')
+  spDF <- convertLayer(dsn=dsnPath,layerName="cb_2013_us_county_20m")
   
   
   # Get STATEFP conversion table from wikipedia. We need this to find state names and codes
-  # from on STATEFP values.
+  # from STATEFP values.
   # URL of STATEFP conversions
   url <- "http://en.wikipedia.org/wiki/Federal_Information_Processing_Standard_state_code"
 
@@ -60,15 +50,22 @@ convertUSCensusCounties <- function(nameOnly=FALSE, ...) {
     return(toString(state[col]))
   }
   
-  # NOTE:  Add MazamaSpatialUtils uniform columns, leaving the originals in place
-  spDF@data$stateCode <- apply(spDF@data, 1, extractState, col='Alpha code')
-  spDF@data$stateName <- apply(spDF@data, 1, extractState, col="Name")
-  spDF@data$countyName <- spDF@data$NAME
+  # Uniform naming
+  spDF$countryCode <- 'US'
+  spDF$countryName <- 'United States'
+  spDF$stateCode <- apply(spDF@data, 1, extractState, col='Alpha code')
+  spDF$stateName <- apply(spDF@data, 1, extractState, col="Name")
+  spDF$countyName <- spDF$NAME
+  
+  spDF <- spDF[,c(6, 8, 9, 10, 11, 12, 13, 14, 2)]
+  names(spDF) <- c('name', 'areaLand', 'areaWater', 'countryCode', 'countryName', 
+                   'stateCode', 'stateName', 'countyName', 'countyFIPS')
   
   # Assign a name and save the data
   assign(datasetName,spDF)
   save(list=c(datasetName),file=paste0(dataDir,"/",datasetName,".RData"))
   
+  # Clean up
   unlink(filePath, force=TRUE)
   unlink(dsnPath, recursive=TRUE, force=TRUE)
   
